@@ -10,7 +10,7 @@ use experimental 'lexical_subs';
 
 use Carp;
 
-use Hash::Wrap { -as => 'wrap_attrs_ro', -immutable => 1, -exists => 'has' };
+use Hash::Wrap 0.11 { -as => 'wrap_attrs_ro', -immutable => 1, -exists => 'has' };
 use Types::Standard qw( Optional Bool );
 use CXC::Number::Sequence::Failure -all;
 use CXC::Number::Sequence::Types -all;
@@ -22,7 +22,7 @@ use enum
 
 use Moo;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 extends 'CXC::Number::Sequence';
 
@@ -397,7 +397,7 @@ CXC::Number::Sequence::Linear - Numeric Sequence with Equal Spacing
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
