@@ -7,7 +7,7 @@ use warnings;
 use feature ':5.24';
 use experimental 'signatures';
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 # ABSTRACT: sequence utilities
 
@@ -20,7 +20,7 @@ use Types::Common::Numeric qw( PositiveInt );
 
 use CXC::Number::Sequence::Failure -all;
 
-use Hash::Wrap { -as => 'wrap_attrs_ro', -immutable => 1, -exists => 'has' };
+use Hash::Wrap 0.11 { -as => 'wrap_attrs_ro', -immutable => 1, -exists => 'has' };
 use Hash::Wrap { -as => 'wrap_attrs_rw' };
 
 use namespace::clean;
@@ -221,7 +221,7 @@ CXC::Number::Sequence::Utils - Utilities for CXC::Number::Sequence generators
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
